Feedforward Closedloop Learning: FeedforwardClosedloopLearningWithFilterbank Class Reference

Feedforward Closedloop Learning

Public Member Functions | List of all members
FeedforwardClosedloopLearningWithFilterbank Class Reference

Derived classes of the FeedforwardClosedloopLearning class for special functionality. More...

`#include <fcl_util.h>`

Inheritance diagram for FeedforwardClosedloopLearningWithFilterbank:
[legend]
Collaboration diagram for FeedforwardClosedloopLearningWithFilterbank:
[legend]

## Public Member Functions
| FeedforwardClosedloopLearningWithFilterbank (int num_of_inputs, int *num_of_neurons_per_layer_array, int num_layers, int num_filtersInput, double minT, double maxT)
| FeedforwardClosedloopLearning with Filterbank at each input. More...
| ~FeedforwardClosedloopLearningWithFilterbank ()
| Destructor.
void | doStep (double *input, double *error)
| Performs the simulation step. More...
void | doStep (double *input, int n1, double *error, int n2)
| Python wrapper function. More...
double | getFilterOutput (int inputIdx, int filterIdx)
int | getNFiltersPerInput ()
Public Member Functions inherited from FeedforwardClosedloopLearning
| FeedforwardClosedloopLearning (int num_of_inputs, int *num_of_neurons_per_layer_array, int _num_layers)
| Constructor: FCL without any filters. More...
| ~FeedforwardClosedloopLearning ()
| Destructor De-allocated any memory. More...
void | doStep (double *input, double *error)
| Performs the simulation step. More...
void | doStep (double *input, int n1, double *error, int n2)
| Python wrapper function. More...
double | getOutput (int index)
| Gets the output from one of the output neurons. More...
void | setLearningRate (double learningRate)
| Sets globally the learning rate. More...
void | setLearningRateDiscountFactor (double _learningRateDiscountFactor)
| Sets how the learnign rate increases or decreases from layer to layer. More...
void | setDecay (double decay)
| Sets a typical weight decay scaled with the learning rate. More...
void | setMomentum (double momentum)
| Sets the global momentum for all layers. More...
void | setActivationFunction (Neuron::ActivationFunction _activationFunction)
| Sets the activation function of the Neuron. More...
void | initWeights (double max=0.001, int initBias=1, Neuron::WeightInitMethod weightInitMethod=Neuron::MAX_OUTPUT_RANDOM)
| Inits the weights in all layers. More...
void | seedRandom (int s)
| Seeds the random number generator. More...
void | setBias (double _bias)
| Sets globally the bias. More...
int | getNumLayers ()
| Gets the total number of layers. More...
Layer * | getLayer (int i)
| Gets a pointer to a layer. More...
Layer * | getOutputLayer ()
| Gets the output layer. More...
int | getNumInputs ()
| Gets the number of inputs. More...
Layer ** | getLayers ()
| Returns all Layers. More...
bool | saveModel (const char *name)
| Saves the whole network. More...
bool | loadModel (const char *name)
| Loads the while network. More...

## Detailed Description

Derived classes of the FeedforwardClosedloopLearning class for special functionality.

## Constructor & Destructor Documentation

## ◆ FeedforwardClosedloopLearningWithFilterbank()

FeedforwardClosedloopLearningWithFilterbank::FeedforwardClosedloopLearningWithFilterbank | ( | int | num_of_inputs,
|  | int * | num_of_neurons_per_layer_array,
|  | int | num_layers,
|  | int | num_filtersInput,
|  | double | minT,
|  | double | maxT
| ) |  |

FeedforwardClosedloopLearning with Filterbank at each input.

Constructor: FCL with a filter bank at the input Every input feeds internally into a has a filter bank of num_filtersInput filters. This allows for a temporal distribution of the inputs.

Parameters

  num_of_inputs | Number of inputs in the input layer
  num_of_neurons_per_layer_array | Number of neurons in each layer
  _num_layers | Number of layer (needs to match with array above)
  num_filtersInput | Number of filters at the input layer, 0 = no filterbank
  num_filters | Number of filters in the hiddel layers (usually zero)
  _minT | Minimum/first temporal duration of the 1st filter
  _maxT | Maximum/last temporal duration of the last filter

## Member Function Documentation

## ◆ doStep() [1/2]

void FeedforwardClosedloopLearningWithFilterbank::doStep | ( | double * | input,
|  | double * | error
| ) |  |

Performs the simulation step.

Parameters

  input | Array with the input values
  error | Array of the error signals

## ◆ doStep() [2/2]

void FeedforwardClosedloopLearningWithFilterbank::doStep | ( | double * | input,
|  | int | n1,
|  | double * | error,
|  | int | n2
| ) |  |

Python wrapper function.

Not public.

The documentation for this class was generated from the following file:

- fcl_util.h